var NAVTREEINDEX15 =
{
"group__spa__utils__defs.html#ga3bca1a11d1c7e8404f9456580acf0676":[10,8,8,1,10],
"group__spa__utils__defs.html#ga3d65c899d0f8937244ed2893d1841f6f":[10,8,8,1,46],
"group__spa__utils__defs.html#ga3fecbba7e4f85f539f62c8db39f12b0a":[10,8,8,1,58],
"group__spa__utils__defs.html#ga48e64fde9ece326caf683b04597614a5":[10,8,8,1,74],
"group__spa__utils__defs.html#ga4a50fbd4b694e2826233b6d54ef3b5a8":[10,8,8,1,67],
"group__spa__utils__defs.html#ga4a52677c41f0a787a3c6624f18647cb6":[10,8,8,1,43],
"group__spa__utils__defs.html#ga57aec3d89182594c8fef7be284f41fff":[10,8,8,1,11],
"group__spa__utils__defs.html#ga58dddf4d57e29beade3b44e156dea532":[10,8,8,1,15],
"group__spa__utils__defs.html#ga59196e4cfb0d8c0a8bdcd909cbbea334":[10,8,8,1,27],
"group__spa__utils__defs.html#ga5b82642b5708ab665c9204338b6cd0e2":[10,8,8,1,61],
"group__spa__utils__defs.html#ga5e46f399b745cda80c6a5a8ab8d5d14f":[10,8,8,1,29],
"group__spa__utils__defs.html#ga6212956dcff36c69fa954f66efaefbcf":[10,8,8,1,77],
"group__spa__utils__defs.html#ga6259b69a24b203050fe69cacac57748a":[10,8,8,1,40],
"group__spa__utils__defs.html#ga632087e970399228667a768ba8424f4e":[10,8,8,1,73],
"group__spa__utils__defs.html#ga6c2a22d6e106ac2f2d69d66a8ed35bd0":[10,8,8,1,41],
"group__spa__utils__defs.html#ga6c3f9f95123f53da37d2bd173bd17ed1":[10,8,8,1,38],
"group__spa__utils__defs.html#ga796e3d4570d8d539ea5886074a646a11":[10,8,8,1,16],
"group__spa__utils__defs.html#ga7b184a799c7168d95deaecab5208f557":[10,8,8,1,47],
"group__spa__utils__defs.html#ga7b3174639eb92d4c045a2bbc72a035df":[10,8,8,1,39],
"group__spa__utils__defs.html#ga7f23cca5e034297bbd1b6860d1dbfdbc":[10,8,8,1,24],
"group__spa__utils__defs.html#ga895eccfd8032e0e9eec102e3b8442f12":[10,8,8,1,17],
"group__spa__utils__defs.html#ga933e7dba5e09dd618617b7b16c0d42fc":[10,8,8,1,52],
"group__spa__utils__defs.html#ga9a615b131c891caac9a73e05b35da09c":[10,8,8,1,68],
"group__spa__utils__defs.html#ga9f2fae4a58cc2e3fdf568d1afc9dc7c1":[10,8,8,1,83],
"group__spa__utils__defs.html#gaa360562916c7e9ab66865f277477f4e6":[10,8,8,1,72],
"group__spa__utils__defs.html#gaa3a2b836ca54d95f207f5557988db748":[10,8,8,1,70],
"group__spa__utils__defs.html#gaa44a69e371d934ab026ae08af1d9b67e":[10,8,8,1,7],
"group__spa__utils__defs.html#gaa495b586c261831b67f09c7f9851aa05":[10,8,8,1,30],
"group__spa__utils__defs.html#gaa92b4913ce779aa401cc714ae829eace":[10,8,8,1,34],
"group__spa__utils__defs.html#gaabdb5fd45bca56878896d7c28204fb88":[10,8,8,1,37],
"group__spa__utils__defs.html#gaad6949f0b0a59d29fdf35ff11ebf83cb":[10,8,8,1,28],
"group__spa__utils__defs.html#gab30712bed8289c9218eb66d9bfeeab78":[10,8,8,1,49],
"group__spa__utils__defs.html#gab4c957beedd4012fd0513f174d7b8b1a":[10,8,8,1,66],
"group__spa__utils__defs.html#gabfdffcb3a4e4e4a488a2ff714e01b3ca":[10,8,8,1,62],
"group__spa__utils__defs.html#gac1ac8f034b73e453c531d928cdfdd8b7":[10,8,8,1,53],
"group__spa__utils__defs.html#gac30327f8b5e6a9c6f9129a73581d09dc":[10,8,8,1,69],
"group__spa__utils__defs.html#gac8080acabcd35c560a15df5e1801afa1":[10,8,8,1,32],
"group__spa__utils__defs.html#gac894bd2d39b2644e1bacf4b11c0a187d":[10,8,8,1,51],
"group__spa__utils__defs.html#gac8965bea56eb75da08e84a547bee992e":[10,8,8,1,50],
"group__spa__utils__defs.html#gacbdd2b8d9e9137bbbd9a38f495c80263":[10,8,8,1,5],
"group__spa__utils__defs.html#gacc9914448bc9fd68ae5ccf004c401bcb":[10,8,8,1,44],
"group__spa__utils__defs.html#gace48f5bc6836a62c328fcac938f8ea6e":[10,8,8,1,14],
"group__spa__utils__defs.html#gaceee1eb1469c2ab68034f5619913bc0d":[10,8,8,1,9],
"group__spa__utils__defs.html#gad485e752b9b897f6434724f669ba72ae":[10,8,8,1,54],
"group__spa__utils__defs.html#gad5b23b2094b330aacd6489da1c8fa7b7":[10,8,8,1,45],
"group__spa__utils__defs.html#gadc0cd747e27d01b74cdd6d3131e3df27":[10,8,8,1,59],
"group__spa__utils__defs.html#gadd03b1b1f299d9249de66ff32bc34569":[10,8,8,1,80],
"group__spa__utils__defs.html#gae1bb114e5bb79da44be5c26e7a9bf6e1":[10,8,8,1,18],
"group__spa__utils__defs.html#gae2c26bfcbc2a33bcfae86018b35fab20":[10,8,8,1,78],
"group__spa__utils__defs.html#gae8ab0b793d870a9725897e695454c12b":[10,8,8,1,26],
"group__spa__utils__defs.html#gae8d35b670e70b6cdba489ca76b5791d4":[10,8,8,1,75],
"group__spa__utils__defs.html#gaec22d2ead4ec1771760219dc16f24709":[10,8,8,1,31],
"group__spa__utils__defs.html#gaf296ce57d6de2645675d2c89fdc8af0a":[10,8,8,1,6],
"group__spa__utils__defs.html#gaf42b2cfc208dc17d25624d84f962b25d":[10,8,8,1,13],
"group__spa__utils__defs.html#gaf5c3a152070995c325caaaf0333269c0":[10,8,8,1,19],
"group__spa__utils__defs.html#gaf7a3ad1f0f015a14f7719022fc6e5a0e":[10,8,8,1,81],
"group__spa__utils__defs.html#gaf88c39fbcce246ddc0e78a934dda87cb":[10,8,8,1,57],
"group__spa__utils__defs.html#gaf8cdb131feb79dfd1d9d1097cb89c052":[10,8,8,1,35],
"group__spa__utils__defs.html#gaf9f1e071334f25ea8580f2509d17fcdd":[10,8,8,1,42],
"group__spa__utils__defs.html#gafa109f3532687323c8f8340f18a15220":[10,8,8,1,76],
"group__spa__utils__defs.html#gafa5449ce6a2352b7966fa923892a46fa":[10,8,8,1,33],
"group__spa__utils__defs.html#gafd41067bab5e0c66b38886f672702dd4":[10,8,8,1,21],
"group__spa__utils__defs.html#gafdcbf720fb6f9ab8a91a0eacdbc3beca":[10,8,8,1,48],
"group__spa__utils__defs.html#gafdd52836cf3dfdc12328615ac44c18e0":[10,8,8,1,12],
"group__spa__utils__defs.html#gga9f2fae4a58cc2e3fdf568d1afc9dc7c1a48000c4ffb67d7fcba31225d2ca9600d":[10,8,8,1,83,0],
"group__spa__utils__defs.html#gga9f2fae4a58cc2e3fdf568d1afc9dc7c1ad27b9a94c88677dfa8681ec43abac456":[10,8,8,1,83,1],
"h264_8h.html":[10,8,7,28],
"hook_8h.html":[10,8,8,5,0],
"hook_8h.html":[10,8,8,4,0],
"iec958_8h.html":[10,8,7,2],
"impl-client_8h.html":[10,5,0,0],
"impl-core_8h.html":[10,5,1,0],
"impl-device_8h.html":[10,5,2,0],
"impl-factory_8h.html":[10,5,3,0],
"impl-interfaces_8h.html":[10,7,4,1],
"impl-link_8h.html":[10,5,4,0],
"impl-metadata_8h.html":[10,5,5,0],
"impl-module_8h.html":[10,5,6,0],
"impl-node_8h.html":[10,5,7,0],
"impl-port_8h.html":[10,5,8,0],
"impl_8h.html":[10,5,17],
"index.html":[],
"index.html#autotoc_md0":[0],
"index.html#autotoc_md1":[1],
"index.html#autotoc_md2":[2],
"index.html#autotoc_md3":[3],
"interfaces_8h.html":[10,7,4,2],
"introspect-funcs_8h.html":[10,7,4,4],
"introspect_8h.html":[10,7,4,3],
"io_8h.html":[10,8,6,2],
"iter_8h.html":[10,8,0,5],
"json-pod_8h.html":[10,3,0],
"json_8h.html":[10,8,8,6,0],
"latency-types_8h.html":[10,8,7,12],
"latency_8h.html":[10,8,7,13],
"layout_8h.html":[10,8,7,3],
"link_8h.html":[10,4,7,0],
"list_8h.html":[10,8,8,3,0],
"local-v4l2_8c-example.html":[13,24],
"log-impl_8h.html":[10,8,9,3,0],
"main-loop_8h.html":[10,4,1,0],
"map_8h.html":[10,6,4,0],
"meta_8h.html":[10,8,1,2],
"metadata_8h.html":[10,7,1,0],
"mjpg_8h.html":[10,8,7,29],
"module_8h.html":[10,4,9,0],
"modules.html":[10],
"monitor_2event_8h.html":[10,8,4,1],
"monitor_2type-info_8h.html":[10,8,4,2],
"multiview_8h.html":[10,8,7,30],
"names_8h.html":[10,8,8,8,0],
"node_2command_8h.html":[10,8,6,0],
"node_2event_8h.html":[10,8,6,1],
"node_2type-info_8h.html":[10,8,6,5],
"page_access.html":[5,5],
"page_access.html#autotoc_md10":[5,5,0],
"page_access.html#autotoc_md11":[5,5,0,0],
"page_access.html#autotoc_md12":[5,5,0,1],
"page_access.html#autotoc_md13":[5,5,0,2],
"page_access.html#autotoc_md14":[5,5,0,3],
"page_access.html#autotoc_md15":[5,5,0,4],
"page_access.html#autotoc_md16":[5,5,1],
"page_access.html#autotoc_md17":[5,5,1,0],
"page_access.html#autotoc_md18":[5,5,1,1],
"page_access.html#autotoc_md19":[5,5,1,2],
"page_api.html":[8],
"page_audio.html":[5,4],
"page_audio.html#autotoc_md100":[5,4,0,5],
"page_audio.html#autotoc_md101":[5,4,0,6],
"page_audio.html#autotoc_md102":[5,4,1],
"page_audio.html#autotoc_md103":[5,4,1,0],
"page_audio.html#autotoc_md104":[5,4,1,1],
"page_audio.html#autotoc_md105":[5,4,1,2],
"page_audio.html#autotoc_md106":[5,4,2],
"page_audio.html#autotoc_md107":[5,4,2,0],
"page_audio.html#autotoc_md94":[5,4,0],
"page_audio.html#autotoc_md95":[5,4,0,0],
"page_audio.html#autotoc_md96":[5,4,0,1],
"page_audio.html#autotoc_md97":[5,4,0,2],
"page_audio.html#autotoc_md98":[5,4,0,3],
"page_audio.html#autotoc_md99":[5,4,0,4],
"page_client_impl.html":[8,0],
"page_client_impl.html#sec_page_client_impl_credentials":[8,0,1],
"page_client_impl.html#sec_page_client_impl_overview":[8,0,0],
"page_client_impl.html#sec_page_client_impl_resources":[8,0,3],
"page_client_impl.html#sec_page_client_impl_types":[8,0,2],
"page_daemon.html":[5,11],
"page_daemon.html#autotoc_md42":[5,11,0],
"page_daemon.html#autotoc_md43":[5,11,0,0],
"page_daemon.html#autotoc_md44":[5,11,1],
"page_design.html":[5,3],
"page_design.html#autotoc_md8":[5,3,0],
"page_design.html#autotoc_md9":[5,3,1],
"page_dma_buf.html":[5,10],
"page_dma_buf.html#autotoc_md157":[5,10,0],
"page_dma_buf.html#autotoc_md158":[5,10,0,0],
"page_dma_buf.html#autotoc_md159":[5,10,0,1],
"page_dma_buf.html#autotoc_md160":[5,10,0,1,0],
"page_dma_buf.html#autotoc_md161":[5,10,0,1,1],
"page_dma_buf.html#autotoc_md162":[5,10,0,2],
"page_dma_buf.html#autotoc_md163":[5,10,0,3],
"page_dma_buf.html#autotoc_md164":[5,10,0,4],
"page_dma_buf.html#autotoc_md165":[5,10,1],
"page_dma_buf.html#autotoc_md166":[5,10,2],
"page_dma_buf.html#autotoc_md167":[5,10,3],
"page_examples.html":[7,7],
"page_library.html":[5,9],
"page_library.html#autotoc_md45":[5,9,0],
"page_library.html#autotoc_md46":[5,9,1],
"page_library.html#autotoc_md47":[5,9,2],
"page_library.html#autotoc_md48":[5,9,3],
"page_library.html#autotoc_md49":[5,9,3,0],
"page_library.html#autotoc_md50":[5,9,3,1],
"page_library.html#autotoc_md51":[5,9,3,2],
"page_library.html#autotoc_md52":[5,9,3,3],
"page_library.html#autotoc_md53":[5,9,3,4],
"page_library.html#autotoc_md54":[5,9,3,5],
"page_library.html#autotoc_md55":[5,9,3,6],
"page_library.html#autotoc_md56":[5,9,3,7],
"page_library.html#autotoc_md57":[5,9,3,8],
"page_library.html#autotoc_md58":[5,9,3,9],
"page_library.html#autotoc_md59":[5,9,4],
"page_library.html#autotoc_md60":[5,9,4,0],
"page_library.html#autotoc_md61":[5,9,4,1],
"page_library.html#autotoc_md62":[5,9,5],
"page_library.html#autotoc_md63":[5,9,6],
"page_library.html#autotoc_md64":[5,9,7],
"page_man_pipewire_1.html":[5,12,0],
"page_man_pipewire_conf_5.html":[5,12,2],
"page_man_pipewire_pulse_1.html":[5,12,1],
"page_man_pw_cat_1.html":[5,12,3],
"page_man_pw_cli_1.html":[5,12,4],
"page_man_pw_dot_1.html":[5,12,5],
"page_man_pw_jack_1.html":[5,12,12],
"page_man_pw_link_1.html":[5,12,6],
"page_man_pw_metadata_1.html":[5,12,7],
"page_man_pw_mididump_1.html":[5,12,8],
"page_man_pw_mon_1.html":[5,12,9],
"page_man_pw_profiler_1.html":[5,12,10],
"page_man_pw_top_1.html":[5,12,11],
"page_midi.html":[5,7],
"page_midi.html#autotoc_md20":[5,7,0],
"page_midi.html#autotoc_md21":[5,7,0,0],
"page_midi.html#autotoc_md22":[5,7,0,1],
"page_midi.html#autotoc_md23":[5,7,0,2],
"page_midi.html#autotoc_md24":[5,7,0,3],
"page_midi.html#autotoc_md25":[5,7,0,4],
"page_midi.html#autotoc_md26":[5,7,1],
"page_midi.html#autotoc_md27":[5,7,1,0],
"page_midi.html#autotoc_md28":[5,7,1,1],
"page_midi.html#autotoc_md29":[5,7,1,2],
"page_midi.html#autotoc_md30":[5,7,2],
"page_midi.html#autotoc_md31":[5,7,2,0],
"page_midi.html#autotoc_md32":[5,7,2,1],
"page_module_access.html":[6,0],
"page_module_adapter.html":[6,1],
"page_module_avb.html":[6,2],
"page_module_client_device.html":[6,3],
"page_module_client_node.html":[6,4],
"page_module_combine_stream.html":[6,5],
"page_module_echo_cancel.html":[6,6],
"page_module_example_sink.html":[6,7],
"page_module_example_source.html":[6,8],
"page_module_fallback_sink.html":[6,9],
"page_module_filter_chain.html":[6,10],
"page_module_link_factory.html":[6,11],
"page_module_loopback.html":[6,12],
"page_module_metadata.html":[6,13],
"page_module_pipe_tunnel.html":[6,14],
"page_module_portal.html":[6,15],
"page_module_profiler.html":[6,16],
"page_module_protocol_native.html":[6,17],
"page_module_protocol_pulse.html":[6,18],
"page_module_protocol_simple.html":[6,19],
"page_module_pulse_tunnel.html":[6,20],
"page_module_raop_discover.html":[6,22],
"page_module_raop_sink.html":[6,21],
"page_module_roc_sink.html":[6,23],
"page_module_roc_source.html":[6,24],
"page_module_rt.html":[6,27],
"page_module_rtp_sink.html":[6,25],
"page_module_rtp_source.html":[6,26],
"page_module_session_manager.html":[6,28],
"page_module_x11_bell.html":[6,29],
"page_module_zeroconf_discover.html":[6,30],
"page_objects_design.html":[5,8],
"page_objects_design.html#autotoc_md68":[5,8,0],
"page_objects_design.html#autotoc_md69":[5,8,0,0],
"page_objects_design.html#autotoc_md70":[5,8,0,1],
"page_objects_design.html#autotoc_md71":[5,8,0,2]
};
